"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.DateTimeUtcToIso = void 0;
const graphql_1 = require("graphql");
const dayjs_1 = __importDefault(require("dayjs"));
const utc_1 = __importDefault(require("dayjs/plugin/utc"));
dayjs_1.default.extend(utc_1.default);
function isIsoDateString(string) {
    const isoDateRegExp = new RegExp(/(\d{4}-[01]\d-[0-3]\dT[0-2]\d:[0-5]\d:[0-5]\d\.\d+([+-][0-2]\d:[0-5]\d|Z))|(\d{4}-[01]\d-[0-3]\dT[0-2]\d:[0-5]\d:[0-5]\d([+-][0-2]\d:[0-5]\d|Z))|(\d{4}-[01]\d-[0-3]\dT[0-2]\d:[0-5]\d([+-][0-2]\d:[0-5]\d|Z))/);
    return isoDateRegExp.test(string);
}
exports.DateTimeUtcToIso = new graphql_1.GraphQLScalarType({
    name: 'DateTime',
    description: 'DateTime ISO 8601',
    serialize(value) {
        if (isIsoDateString(value)) {
            return value;
        }
        return dayjs_1.default.utc(value).format('YYYY-MM-DDTHH:mm:ss[Z]');
    },
    parseValue(value) {
        if (!(typeof value === 'string')) {
            throw new TypeError(`DateTime cannot represent non string type ${JSON.stringify(value)}`);
        }
        if (!isIsoDateString(value)) {
            throw new TypeError(`DateTime cannot represent an invalid date-time-string ${value}.`);
        }
        return dayjs_1.default.utc(value).format('YYYY-MM-DDTHH:mm:ss');
    },
    parseLiteral(ast) {
        if (ast.kind !== graphql_1.Kind.STRING) {
            throw new TypeError(`DateTime cannot represent non string type ${'value' in ast && ast.value}`);
        }
        const { value } = ast;
        if (!isIsoDateString(value)) {
            throw new TypeError(`DateTime cannot represent an invalid date-time-string ${String(value)}.`);
        }
        return dayjs_1.default.utc(value).format('YYYY-MM-DDTHH:mm:ss');
    }
});
//# sourceMappingURL=DateTimeUtcToIso.js.map